import fixtures


class EnableFakeSensors(fixtures.Fixture):
    """Fixture to enable fake sensors."""

    def __init__(self, job, sensors, clean_up=True):
        super().__init__()
        self.job = job()
        self.sensors = sensors()
        self.clean_up = clean_up

    def setUp(self):
        super().setUp()
        if not self.are_fake_sensors_enabled():
            self.enable_fake_sensors()
        if self.clean_up:
            self.addCleanup(self.job.restart)

    def enable_fake_sensors(self):
        """Enable fake sensors on the job process."""
        self.job.restart(fake_sensors=True)
        self.sensors.validate_fifo_ready(self.job.name)
        self.sensors.setup_sensors(self.job.name)

    def are_fake_sensors_enabled(self):
        """Return True if fake sensors enabled."""
        try:
            pid = self.job.get_pid()
        except ValueError:
            return False
        return self.sensors.are_fake_sensors_enabled_for_process(pid)
