# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
#
# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from ubuntu_system_tests.helpers import context


def get_keyboard():
    """Return keyboard proxy object."""
    if 'keyboard' not in context.shared or not context.shared.keyboard:
        from ubuntu_keyboard.emulators.keyboard import Keyboard
        context.shared.keyboard = Keyboard()
    return context.shared.keyboard


def get_osk_area():
    """Return globalRect of OSK."""
    return get_keyboard().active_keypad.globalRect


def is_osk_showing():
    """Return True if keyboard is showing on screen."""
    return get_keyboard().is_available()


def dismiss_keyboard():
    """Dismiss the OSK if it is showing."""
    if is_osk_showing():
        get_keyboard().dismiss()


def is_item_obscured_by_osk(item):
    """Return True if specified item is within OSK screen area."""
    if is_osk_showing():
        osk_area = get_osk_area()
        item_area = item.globalRect
        item_bottom_y = item_area.y + item_area.height
        return item_bottom_y >= osk_area.y
    return False
