# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from subprocess import CalledProcessError

from ubuntu_system_tests.helpers import wait_until
from ubuntu_system_tests.helpers.job import JobBase


class RepowerdJob(JobBase):
    """This class contain the specific implementation of Repowerd job which is
    is a system daemon that helps manage power states
    """

    def __init__(self, sudo=True):
        super().__init__('repowerd', sudo)

    def start(self, fake_sensors=False, **kwargs):
        """Start a new repowerd process.
        :param fake_sensors: If True then enable fake sensors,
        otherwise use real sensors.
        """
        cmd = self.start_command
        if fake_sensors:
            cmd += ' UBUNTU_PLATFORM_API_TEST_OVERRIDE=sensors'
        JobBase._run_command(cmd, self.sudo, **kwargs)

    def restart(self, fake_sensors=False):
        """Restart repowerd process, stopping existing process if running.
        :param fake_sensors: If True then enable fake sensors, otherwise use
        real sensors.
        """
        try:
            pid = self.get_pid()
        except CalledProcessError:
            pass
        else:
            self.stop()
            JobBase._run_command('rm -f /tmp/sensor-fifo-{}'.format(pid),
                                 self.sudo)
        self.start(fake_sensors=fake_sensors)
        wait_until(self.is_running)
