# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2015, 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

import ubuntuone_credentials

from ubuntuuitoolkit import UbuntuUIToolkitCustomProxyObjectBase

from ubuntu_system_tests.helpers.autopilot import validate_dbus_object
from ubuntu_system_tests.helpers.ubuntuuitoolkit import _flickable

APP_PATH_ROOT = b'online-accounts-ui'


class OnlineAccountsUI(UbuntuUIToolkitCustomProxyObjectBase):

    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(
            path, state, APP_PATH_ROOT, APP_PATH_ROOT)

    @property
    def accounts_creation_page(self):
        page = self.select_single(AccountCreationPage)
        page.visible.wait_for(True)
        return page


class AccountCreationPage(ubuntuone_credentials.NewAccount):

    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(
            path, state, APP_PATH_ROOT, b'AccountCreationPage')

    def move_item_into_view(self, item):
        self._get_flickable().swipe_child_into_view(item)

    def _get_flickable(self):
        return self.select_single(Main)

    def _get_new_password_textfield(self):
        return self.select_single(objectName='newPasswordTextField')

    def _get_confirm_password_textfield(self):
        return self.select_single(objectName='confirmPasswordTextField')

    def _get_terms_checkbox(self):
        return self.select_single(objectName='termsAndConditionsCheckBox')

    def _enter_password_new_user(self, password):
        password_field = self._get_new_password_textfield()
        self.move_item_into_view(password_field)
        password_field.write(password)

    def _enter_password_confirmation(self, password):
        password_field = self._get_confirm_password_textfield()
        self.move_item_into_view(password_field)
        password_field.write(password)

    def _agree_to_terms(self, agree):
        checkbox = self._get_terms_checkbox()
        self.move_item_into_view(checkbox)
        if agree:
            checkbox.check()
        else:
            checkbox.uncheck()

    def switch_to_new_account(self):
        new_user_label = self.select_single(objectName='loginFormToggleLabel')
        self.pointing_device.click_object(new_user_label)


class Main(_flickable.QQuickFlickable):

    @classmethod
    def validate_dbus_object(cls, path, state):
        return validate_dbus_object(
            path, state, APP_PATH_ROOT, b'Main')
