
# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import logging

from ubuntuuitoolkit._custom_proxy_objects._flickable import QQuickFlickable

from ubuntu_system_tests.helpers import maliit

logger = logging.getLogger(__name__)


class QQuickFlickable(QQuickFlickable):
    """Extend QQuickFlickable from Ubuntu UI Toolkit."""

    def swipe_child_into_view(self, child):
        """Over-ride base class helper to take account of OSK showing."""
        super().swipe_child_into_view(child)
        self.move_item_above_osk(child)
        child.wait_until_not_moving()

    def move_upwards(self):
        """Swipe the flickable object upwards slightly."""
        rate = self._slow_drag_rate()
        start_x = stop_x = self.globalRect.x + (self.globalRect.width // 2)
        start_y = self.globalRect.y + (self.globalRect.height // 2)
        stop_y = self.globalRect.y + (self.globalRect.height // 4)
        self._slow_drag(start_x, stop_x, start_y, stop_y, rate)
        self.dragging.wait_for(False)
        self.moving.wait_for(False)

    def move_item_above_osk(self, item):
        """Move an item into view if it is obscured by OSK."""
        if maliit.is_osk_showing():
            previous_rect = item.globalRect
            while maliit.is_item_obscured_by_osk(item):
                self.move_upwards()
                if item.globalRect == previous_rect:
                    logger.info('Cannot swipe item into view.')
                    break
