# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#

from autopilot.introspection import is_element
# TODO: Remove this when extending from ubuntuuitoolkit main view
from ubuntuuitoolkit._custom_proxy_objects import _tabs

# TODO: We should actually extend our views from ubuntuuitoolkit MainView
# but that view does not differentiate between single tab and multitab
# views. Once that difference is implemented in ubuntuuitoolkit, then we
# just import ubuntuuitoolkit here
import ubuntuuitoolkit


class SingleTabMainView:
    pass


class MultiTabMainView(ubuntuuitoolkit.UbuntuUIToolkitCustomProxyObjectBase):

    @classmethod
    def validate_dbus_object(cls, path, state):
        return False

    def _get_overflow_panel(self):
        return self.wait_select_single(
            objectName='actions_overflow_panel')

    def _get_overflow_actions(self):
        return self.select_single(
            objectName='overflow_action_button', visible=True)

    def _get_tab_action(self, tab_name):
        return self.select_single(
            'UCAbstractButton', text=tab_name, visible=True)

    def _get_tabs(self):
        """Return the Tabs custom proxy object of the MainView."""
        return self.select_single(_tabs.Tabs)

    def click_action_button(self, action_text):
        """Clicks on a given action"""
        tab_action = self._get_tab_action(action_text)
        self.pointing_device.click_object(tab_action)
        self._get_tabs().get_current_tab().title.wait_for(action_text)

    def open_actions_panel(self):
        """
        Checks if the overflow actions panel is visible and
        opens it if it was not
        """
        if not is_element(self._get_overflow_panel):
            actions = self._get_overflow_actions()
            self.pointing_device.click_object(actions)

        overflow_panel = self._get_overflow_panel()
        overflow_panel.visible.wait_for(True)

    def switch_to_tab(self, tab_name):
        """Open a tab.
        :parameter tab_name: The tab name where we need to switch to.
        """
        current_tab = self._get_tabs().get_current_tab()
        if not current_tab.title == tab_name:
            self.open_actions_panel()
            self.click_action_button(tab_name)
