# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-

#
# Ubuntu System Tests
# Copyright (C) 2016 Canonical
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
from ubuntu_system_tests.helpers import context
from ubuntu_system_tests.helpers import try_import
from ubuntu_system_tests.helpers.sensors import SensorsBase

unity_sensors = try_import('unity8.sensors')

ORIENTATION_TOP_UP = 'top_up'
ORIENTATION_TOP_DOWN = 'top_down'
ORIENTATION_LEFT_UP = 'left_up'
ORIENTATION_RIGHT_UP = 'right_up'
ACCEL_SENSOR_RESOLUTION = 0.1
ACCEL_SENSOR_MAX = 1000
ACCEL_SENSOR_MIN = 0


class Unity8Sensors(SensorsBase):

    @staticmethod
    def get_fake_sensors_setup_commands():
        """Return list of commands required to configure the fake sensors."""
        cmds = [
            'create accel {} {} {}'.format(
                ACCEL_SENSOR_MIN, ACCEL_SENSOR_MAX, ACCEL_SENSOR_RESOLUTION)]
        return cmds

    @staticmethod
    def set_orientation(orientation):
        """Set orientation sensor to specified value.
        :param orientation: Orientation to set.
        """
        unity_sensors.FakePlatformSensors(
            context.shared.get('unity_pid')).set_orientation(orientation)

    def set_orientation_top_up(self):
        """Set accelerometer sensor orientation to top edge up."""
        self.set_orientation(ORIENTATION_TOP_UP)

    def set_orientation_top_down(self):
        """Set accelerometer sensor orientation to top edge down."""
        self.set_orientation(ORIENTATION_TOP_DOWN)

    def set_orientation_left_up(self):
        """Set accelerometer sensor orientation to left edge up."""
        self.set_orientation(ORIENTATION_LEFT_UP)

    def set_orientation_right_up(self):
        """Set accelerometer sensor orientation to right edge up."""
        self.set_orientation(ORIENTATION_RIGHT_UP)
